rm: only refresh entries that we may touch
This gets rid of the whole tree cache refresh. Instead only path that we touch will get refreshed. We may still lstat() more than needed, but it'd be better playing safe. This potentially reduces a large number of lstat() on big trees. Take gentoo-x86 tree for example, which has roughly 80k files: Unmodified Git: $ time git rm --cached skel.ebuild rm 'skel.ebuild' real 0m1.441s user 0m0.821s sys 0m0.531s Modified Git: $ time ~/w/git/git rm --cached skel.ebuild rm 'skel.ebuild' real 0m0.941s user 0m0.828s sys 0m0.091s Signed-off-by: Nguyễn Thái Ngọc Duy <pclouds@gmail.com> Signed-off-by: Junio C Hamano <gitster@pobox.com>
Nguyễn Thái Ngọc Duy committed
Jan 17, 2010 at 15:43 UTC
4e1a7baa2e466afded9ff50b9a4539b24dbd3584
1 file changed
+2
-1
builtin-rm.c
+2
-1
@@ -169,9 +169,10 @@ int cmd_rm(int argc, const char **argv, const char *prefix)
169
170
if (read_cache() < 0)
171
die("index file corrupt");
172
- refresh_cache(REFRESH_QUIET);
172
173
pathspec = get_pathspec(prefix, argv);
174
+ refresh_index(&the_index, REFRESH_QUIET, pathspec, NULL, NULL);
175
+
176
seen = NULL;
177
for (i = 0; pathspec[i] ; i++)
178
/* nothing */;